Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AuthConfiguration ¶
type AuthConfiguration struct {
Password string `yaml:"password"`
Username string `yaml:"username"`
}
AuthConfiguration contains credentials for authenticating with the broker
type Config ¶
type Config struct {
ServiceConfiguration ServiceConfiguration `yaml:"service"`
AuthConfiguration AuthConfiguration `yaml:"auth"`
Host string `yaml:"backend_host"`
Port string `yaml:"backend_port"`
Namespace string `yaml:"namespace"`
}
Config represents the configuration for the entire server
type Plan ¶
type Plan struct {
ID string `yaml:"plan_id"`
Name string `yaml:"plan_name"`
Description string `yaml:"description"`
StorageClass *string `yaml:"kube_storage_class"`
Free bool `yaml:"free"`
DefaultSize string `yaml:"default_size"`
DefaultAccessMode string `yaml:"default_access_mode"`
}
Plan represents a Broker plan for a Kubernetes storage class
type ServiceConfiguration ¶
type ServiceConfiguration struct {
ServiceName string `yaml:"service_name"`
ServiceID string `yaml:"service_id"`
Plans []Plan `yaml:"plans"`
Description string `yaml:"description"`
LongDescription string `yaml:"long_description"`
ProviderDisplayName string `yaml:"provider_display_name"`
DocumentationURL string `yaml:"documentation_url"`
SupportURL string `yaml:"support_url"`
DisplayName string `yaml:"display_name"`
IconImage string `yaml:"icon_image"`
}
ServiceConfiguration represents the configuration for the Eirini Kubernetes Volume Broker
Click to show internal directories.
Click to hide internal directories.